==> jc-1.4.0.tar.gz: polyglot/util/InternalCompilerError.h <==
// public class polyglot.util.InternalCompilerError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 22b321d488641c54 polyglot_util_InternalCompilerError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_util_InternalCompilerError_H_
#define _JC_polyglot_util_InternalCompilerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_InternalCompilerError$sub_refs	_jc_polyglot_util_InternalCompilerError$sub_refs;
typedef struct _jc_polyglot_util_InternalCompilerError$sub_nonrefs	_jc_polyglot_util_InternalCompilerError$sub_nonrefs;
typedef struct _jc_polyglot_util_InternalCompilerError$refs	_jc_polyglot_util_InternalCompilerError$refs;
typedef struct _jc_polyglot_util_InternalCompilerError$nonrefs	_jc_polyglot_util_InternalCompilerError$nonrefs;
typedef struct _jc_polyglot_util_InternalCompilerError$object	_jc_polyglot_util_InternalCompilerError$object;

typedef const struct _jc_polyglot_util_InternalCompilerError$vmethods	_jc_polyglot_util_InternalCompilerError$vmethods;
typedef const struct _jc_polyglot_util_InternalCompilerError$vtable	_jc_polyglot_util_InternalCompilerError$vtable;
typedef const struct _jc_polyglot_util_InternalCompilerError$vtype	_jc_polyglot_util_InternalCompilerError$vtype;

// Constructors
extern void _jc_polyglot_util_InternalCompilerError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_util_InternalCompilerError$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_polyglot_util_InternalCompilerError$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);
extern void _jc_polyglot_util_InternalCompilerError$method$_init$2fa010c7766ce779(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_polyglot_util_InternalCompilerError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_polyglot_util_InternalCompilerError$method$_init$e1025501fac123ee(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_util_InternalCompilerError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_InternalCompilerError$method$message$323342d7f00d6406(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_util_InternalCompilerError$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$message$323342d7f00d6406;
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$position$bb89333b1e4c840c;

// Virtual methods structure
struct _jc_polyglot_util_InternalCompilerError$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);
	struct _jc_java_lang_String$object	*(*message$323342d7f00d6406)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *);
};

// Vtable
struct _jc_polyglot_util_InternalCompilerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_InternalCompilerError$vmethods	polyglot_util_InternalCompilerError;
};

// Vtype
struct _jc_polyglot_util_InternalCompilerError$vtype {
	_jc_type			type;
	_jc_polyglot_util_InternalCompilerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_InternalCompilerError$sub_refs {
	struct _jc_polyglot_util_Position$object	*pos;
};

// Reference instance fields (object)
struct _jc_polyglot_util_InternalCompilerError$refs {
    _jc_polyglot_util_InternalCompilerError$sub_refs	polyglot_util_InternalCompilerError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_InternalCompilerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_InternalCompilerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_InternalCompilerError$sub_nonrefs	polyglot_util_InternalCompilerError;
};

// Object instance structure
struct _jc_polyglot_util_InternalCompilerError$object {
	_jc_polyglot_util_InternalCompilerError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_InternalCompilerError$vtype	*vtype;
	_jc_polyglot_util_InternalCompilerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_InternalCompilerError$vtype _jc_polyglot_util_InternalCompilerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_InternalCompilerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_InternalCompilerError$class_object;

#endif	/* _JC_polyglot_util_InternalCompilerError_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/InternalCompilerError.h <==
// public class polyglot.util.InternalCompilerError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 22b321d488641c54 polyglot_util_InternalCompilerError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_util_InternalCompilerError_H_
#define _JC_polyglot_util_InternalCompilerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_InternalCompilerError$sub_refs	_jc_polyglot_util_InternalCompilerError$sub_refs;
typedef struct _jc_polyglot_util_InternalCompilerError$sub_nonrefs	_jc_polyglot_util_InternalCompilerError$sub_nonrefs;
typedef struct _jc_polyglot_util_InternalCompilerError$refs	_jc_polyglot_util_InternalCompilerError$refs;
typedef struct _jc_polyglot_util_InternalCompilerError$nonrefs	_jc_polyglot_util_InternalCompilerError$nonrefs;
typedef struct _jc_polyglot_util_InternalCompilerError$object	_jc_polyglot_util_InternalCompilerError$object;

typedef const struct _jc_polyglot_util_InternalCompilerError$vmethods	_jc_polyglot_util_InternalCompilerError$vmethods;
typedef const struct _jc_polyglot_util_InternalCompilerError$vtable	_jc_polyglot_util_InternalCompilerError$vtable;
typedef const struct _jc_polyglot_util_InternalCompilerError$vtype	_jc_polyglot_util_InternalCompilerError$vtype;

// Constructors
extern void _jc_polyglot_util_InternalCompilerError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_InternalCompilerError$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_InternalCompilerError$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_InternalCompilerError$method$_init$2fa010c7766ce779(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_InternalCompilerError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_InternalCompilerError$method$_init$e1025501fac123ee(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_util_InternalCompilerError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_InternalCompilerError$method$message$323342d7f00d6406(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_util_InternalCompilerError$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$message$323342d7f00d6406;
extern _jc_method _jc_polyglot_util_InternalCompilerError$method_info$position$bb89333b1e4c840c;

// Virtual methods structure
struct _jc_polyglot_util_InternalCompilerError$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*message$323342d7f00d6406)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_util_InternalCompilerError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_InternalCompilerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_util_InternalCompilerError$vmethods	polyglot_util_InternalCompilerError;
};

// Vtype
struct _jc_polyglot_util_InternalCompilerError$vtype {
	_jc_type			type;
	_jc_polyglot_util_InternalCompilerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_InternalCompilerError$sub_refs {
	struct _jc_polyglot_util_Position$object	*pos;
};

// Reference instance fields (object)
struct _jc_polyglot_util_InternalCompilerError$refs {
    _jc_polyglot_util_InternalCompilerError$sub_refs	polyglot_util_InternalCompilerError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_InternalCompilerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_InternalCompilerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_util_InternalCompilerError$sub_nonrefs	polyglot_util_InternalCompilerError;
};

// Object instance structure
struct _jc_polyglot_util_InternalCompilerError$object {
	_jc_polyglot_util_InternalCompilerError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_InternalCompilerError$vtype	*vtype;
	_jc_polyglot_util_InternalCompilerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_InternalCompilerError$vtype _jc_polyglot_util_InternalCompilerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_InternalCompilerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_InternalCompilerError$class_object;

#endif	/* _JC_polyglot_util_InternalCompilerError_H_ */
